summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorfukachan <fukachan>2002-04-08 12:44:23 +0000
committerfukachan <fukachan>2002-04-08 12:44:23 +0000
commite9c3232c32af513158511779a0d5aeb5fdc6d168 (patch)
treecec6d6513fdff173cac2f0743fcb2b96630e5713
parente8ac0083ef6c5d462743f455610d049d6cb17bc5 (diff)
downloadfml8-e9c3232c32af513158511779a0d5aeb5fdc6d168.tar.gz
fml8-e9c3232c32af513158511779a0d5aeb5fdc6d168.tar.bz2
fml8-e9c3232c32af513158511779a0d5aeb5fdc6d168.zip
fix/clean up documents
-rw-r--r--fml/lib/FML/Command/SendFile.pm6
-rw-r--r--fml/lib/FML/Filter/BodyCheck.pm4
-rw-r--r--fml/lib/FML/Filter/ContentCheck.pm4
-rw-r--r--fml/lib/FML/Filter/HeaderCheck.pm4
-rw-r--r--fml/lib/FML/Header.pm4
-rw-r--r--fml/lib/FML/Language/Japanese/Utils.pm16
-rw-r--r--fml/lib/FML/Process/CGI/Param.pm8
-rw-r--r--fml/lib/FML/Process/Command.pm14
-rw-r--r--fml/lib/FML/Process/HTMLify.pm4
-rw-r--r--fml/lib/FML/Process/Switch.pm11
-rw-r--r--fml/lib/File/Sequence.pm6
-rw-r--r--fml/lib/File/Utils.pm4
-rw-r--r--fml/lib/IO/File/Atomic.pm9
-rw-r--r--fml/lib/Mail/Delivery/Queue.pm4
-rw-r--r--fml/lib/Mail/Message.pm6
-rw-r--r--fml/lib/Mail/Message/MH.pm6
16 files changed, 56 insertions, 54 deletions
diff --git a/fml/lib/FML/Command/SendFile.pm b/fml/lib/FML/Command/SendFile.pm
index 0373e796..6dc37421 100644
--- a/fml/lib/FML/Command/SendFile.pm
+++ b/fml/lib/FML/Command/SendFile.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: SendFile.pm,v 1.14 2002/03/30 13:48:26 fukachan Exp $
+# $FML: SendFile.pm,v 1.15 2002/04/07 12:13:03 fukachan Exp $
#
package FML::Command::SendFile;
@@ -102,7 +102,7 @@ sub send_article
# Descriptions: check the argument and expand it if needed
# Arguments: OBJ($self) OBJ($curproc) STR($fn)
# Side Effects: none
-# Return Value: HASH_ARRAY as [ $fist .. $last ]
+# Return Value: ARRAY_REF as [ $fist .. $last ]
sub _is_valid_argument
{
my ($self, $curproc, $fn) = @_;
@@ -149,7 +149,7 @@ sub _is_valid_argument
# This array is composed of article numbers.
# Arguments: NUM($first_number) NUM($last_number)
# Side Effects: none
-# Return Value: HASH_ARRAY as [ $first .. $last ]
+# Return Value: ARRAY_REF as [ $first .. $last ]
sub _expand_range
{
my ($first, $last) = @_;
diff --git a/fml/lib/FML/Filter/BodyCheck.pm b/fml/lib/FML/Filter/BodyCheck.pm
index 45f4f30f..cfe7ee25 100644
--- a/fml/lib/FML/Filter/BodyCheck.pm
+++ b/fml/lib/FML/Filter/BodyCheck.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: BodyCheck.pm,v 1.14 2002/01/16 13:33:59 fukachan Exp $
+# $FML: BodyCheck.pm,v 1.15 2002/01/16 13:43:19 fukachan Exp $
#
package FML::Filter::BodyCheck;
@@ -68,7 +68,7 @@ overwrite rules by specified C<@$rules> ($rules is HASH ARRAY).
# Descriptions: access method to overwrite rule
-# Arguments: OBJ($self) HASH_ARRAY($rarray)
+# Arguments: OBJ($self) ARRAY_REF($rarray)
# Side Effects: overwrite info in object
# Return Value: none
sub rules
diff --git a/fml/lib/FML/Filter/ContentCheck.pm b/fml/lib/FML/Filter/ContentCheck.pm
index 7bc58311..9c480204 100644
--- a/fml/lib/FML/Filter/ContentCheck.pm
+++ b/fml/lib/FML/Filter/ContentCheck.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML$
+# $FML: ContentCheck.pm,v 1.1 2002/04/07 15:01:09 tmu Exp $
#
package FML::Filter::ContentCheck;
@@ -62,7 +62,7 @@ overwrite rules by specified C<@$rules> ($rules is HASH ARRAY).
# Descriptions: access method to overwrite rule
-# Arguments: OBJ($self) HASH_ARRAY($rarray)
+# Arguments: OBJ($self) ARRAY_REF($rarray)
# Side Effects: overwrite info in object
# Return Value: none
sub rules
diff --git a/fml/lib/FML/Filter/HeaderCheck.pm b/fml/lib/FML/Filter/HeaderCheck.pm
index 69af8709..660b373d 100644
--- a/fml/lib/FML/Filter/HeaderCheck.pm
+++ b/fml/lib/FML/Filter/HeaderCheck.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: HeaderCheck.pm,v 1.11 2002/01/16 13:43:19 fukachan Exp $
+# $FML: HeaderCheck.pm,v 1.12 2002/02/01 12:03:56 fukachan Exp $
#
package FML::Filter::HeaderCheck;
@@ -65,7 +65,7 @@ overwrite rules by specified C<@$rules> ($rules is HASH ARRAY).
# Descriptions: access method to overwrite rule
-# Arguments: OBJ($self) HASH_ARRAY($rarray)
+# Arguments: OBJ($self) ARRAY_REF($rarray)
# Side Effects: overwrite info in object
# Return Value: none
sub rules
diff --git a/fml/lib/FML/Header.pm b/fml/lib/FML/Header.pm
index c9e2cc22..7936cac6 100644
--- a/fml/lib/FML/Header.pm
+++ b/fml/lib/FML/Header.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Header.pm,v 1.38 2001/12/22 09:21:01 fukachan Exp $
+# $FML: Header.pm,v 1.39 2001/12/23 09:20:41 fukachan Exp $
#
package FML::Header;
@@ -458,7 +458,7 @@ sub delete_subject_tag_like_string
# In-Reply-To: and References: fields.
# Arguments: OBJ($header)
# Side Effects: none
-# Return Value: HASH_ARRAY
+# Return Value: ARRAY_REF
sub extract_message_id_references
{
my ($header) = @_;
diff --git a/fml/lib/FML/Language/Japanese/Utils.pm b/fml/lib/FML/Language/Japanese/Utils.pm
index 6d0b8ded..4f53b2cd 100644
--- a/fml/lib/FML/Language/Japanese/Utils.pm
+++ b/fml/lib/FML/Language/Japanese/Utils.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Utils.pm,v 1.6 2002/02/01 12:03:56 fukachan Exp $
+# $FML: Utils.pm,v 1.7 2002/02/02 08:04:53 fukachan Exp $
#
package FML::Language::Japanese::Utils;
@@ -16,7 +16,7 @@ my $debug = 0;
=head1 NAME
-FML::Language::Japanese::Utils - what is this
+FML::Language::Japanese::Utils - functions to handle Japanese srings
=head1 SYNOPSIS
@@ -45,7 +45,7 @@ require Exporter;
# Descriptions: $buf looks like Japanese or not ?
# Arguments: STR($buf)
# Side Effects: none
-# Return Value: 1 or 0
+# Return Value: NUM(1 or 0)
sub is_iso2022jp_string
{
my ($buf) = @_;
@@ -58,9 +58,9 @@ sub is_iso2022jp_string
# Koji Sudo <koji@cherry.or.jp>
# Takahiro Kambe <taca@sky.yamashina.kyoto.jp>
# check the given buffer has unusual Japanese (not ISO-2022-JP)
-# Arguments: OBJ($buf)
+# Arguments: STR($buf)
# Side Effects: none
-# Return Value: 1 or 0
+# Return Value: NUM(1 or 0)
sub _look_not_iso2022jp_string
{
my ($buf) = @_;
@@ -98,11 +98,11 @@ return 1 if found or 0 if not.
# Descriptions: compare Japanese EUC strings
-# fml 4.0: EUCCompare($buf, $pat)
-# where $pat should be $& (matched pattern)
# Arguments: OBJ($self) STR($a) STR($pat)
# Side Effects: none
-# Return Value: 1 or 0
+# History: fml 4.0: EUCCompare($buf, $pat)
+# where $pat should be $& (matched pattern)
+# Return Value: NUM(1 or 0)
sub compare_euc_string
{
my ($self, $a, $pat) = @_;
diff --git a/fml/lib/FML/Process/Command.pm b/fml/lib/FML/Process/Command.pm
index 6f97a3e0..884f358e 100644
--- a/fml/lib/FML/Process/Command.pm
+++ b/fml/lib/FML/Process/Command.pm
@@ -3,7 +3,7 @@
# Copyright (C) 2000,2001,2002 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML: Command.pm,v 1.40 2002/03/23 12:22:03 fukachan Exp $
+# $FML: Command.pm,v 1.41 2002/03/30 11:08:36 fukachan Exp $
#
package FML::Process::Command;
@@ -11,11 +11,9 @@ package FML::Process::Command;
use vars qw($debug @ISA @EXPORT @EXPORT_OK);
use strict;
use Carp;
-
-use FML::Process::Kernel;
use FML::Log qw(Log LogWarn LogError);
use FML::Config;
-
+use FML::Process::Kernel;
@ISA = qw(FML::Process::Kernel);
@@ -228,7 +226,7 @@ sub _pre_scan
# syntax check, permission of command use et. al.
# Arguments: OBJ($self) HASH_REF($args) HASH_REF($opts)
# Side Effects: none
-# Return Value: 1 or 0
+# Return Value: NUM(1 or 0)
sub _is_valid_command
{
my ($curproc, $args, $mode, $opts) = @_;
@@ -264,7 +262,7 @@ sub _is_valid_command
# argument vector after command name
# Arguments: STR($command) STR($comname)
# Side Effects: none
-# Return Value: HASH_ARRAY
+# Return Value: ARRAY_REF
sub _parse_command_options
{
my ($command, $comname) = @_;
@@ -297,6 +295,10 @@ sub _get_command_name
}
+# Descriptions: authenticate the currrent process sender as an admin
+# Arguments: OBJ($curproc) HASH_REF($args) HASH_REF($optargs)
+# Side Effects: none
+# Return Value: NUM(1 or 0)
sub _auth_admin
{
my ($curproc, $args, $optargs) = @_;
diff --git a/fml/lib/FML/Process/HTMLify.pm b/fml/lib/FML/Process/HTMLify.pm
index e5c80679..e993bf93 100644
--- a/fml/lib/FML/Process/HTMLify.pm
+++ b/fml/lib/FML/Process/HTMLify.pm
@@ -1,9 +1,9 @@
#-*- perl -*-
#
-# Copyright (C) 2000-2001,2002 Ken'ichi Fukamachi
+# Copyright (C) 2001,2002 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML: HTMLify.pm,v 1.12 2002/03/17 06:24:31 fukachan Exp $
+# $FML: HTMLify.pm,v 1.13 2002/03/31 03:39:14 fukachan Exp $
#
package FML::Process::HTMLify;
diff --git a/fml/lib/FML/Process/Switch.pm b/fml/lib/FML/Process/Switch.pm
index e8d57f71..fceef975 100644
--- a/fml/lib/FML/Process/Switch.pm
+++ b/fml/lib/FML/Process/Switch.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Switch.pm,v 1.60 2002/04/01 23:41:13 fukachan Exp $
+# $FML: Switch.pm,v 1.61 2002/04/07 12:25:25 fukachan Exp $
#
package FML::Process::Switch;
@@ -14,6 +14,7 @@ use Carp;
use vars qw($debug);
use File::Spec;
+
=head1 NAME
FML::Process::Switch - dispatch the suitable module
@@ -197,7 +198,7 @@ sub main::Bootstrap2
# Descriptions: analyze argument vector
# Arguments: STR($myname) HASH_REF($main_cf)
# Side Effects: none
-# Return Value: HASH_ARRAY (list of config.cf's)
+# Return Value: ARRAY_REF (list of config.cf's)
sub _parse_argv
{
my ($myname, $main_cf) = @_;
@@ -214,7 +215,7 @@ sub _parse_argv
# Descriptions: analyze argument vector
# Arguments: STR($myname) HASH_REF($main_cf)
# Side Effects: none
-# Return Value: HASH_ARRAY (list of config.cf's)
+# Return Value: ARRAY_REF (list of config.cf's)
sub _usual_parse_argv
{
my ($myname, $main_cf) = @_;
@@ -264,7 +265,7 @@ sub _usual_parse_argv
# Descriptions: analyze argument vector
# Arguments: STR($myname) HASH_REF($main_cf)
# Side Effects: none
-# Return Value: HASH_ARRAY (list of config.cf's)
+# Return Value: ARRAY_REF (list of config.cf's)
sub _makefml_parse_argv
{
my ($myname, $main_cf) = @_;
@@ -435,7 +436,7 @@ sub _module_specific_options
# Descriptions: this program ($0) requires ML name always or not?
# Arguments: STR($myname)
# Side Effects: none
-# Return Value: 1 (require ml name always) or 0
+# Return Value: NUM(1 (require ml name always) or 0)
sub _ml_name_is_required
{
my ($myname) = @_;
diff --git a/fml/lib/File/Sequence.pm b/fml/lib/File/Sequence.pm
index 901ae9a2..5ae3d855 100644
--- a/fml/lib/File/Sequence.pm
+++ b/fml/lib/File/Sequence.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Sequence.pm,v 1.21 2002/02/27 09:20:34 tmu Exp $
+# $FML: Sequence.pm,v 1.22 2002/04/03 11:33:00 fukachan Exp $
#
package File::Sequence;
@@ -79,7 +79,7 @@ get the sequence number from specified C<$file>.
=cut
-# Descriptions: constructor
+# Descriptions: ordinary constructor
# Arguments: OBJ($self) HASH_REF($args)
# Side Effects: object itself holds a few local _variables
# Return Value: OBJ
@@ -94,7 +94,7 @@ sub new
}
-# Descriptions: increment sequence
+# Descriptions: increment the sequence number
# Arguments: OBJ($self) [STR($file)]
# If $file is not specified,
# the sequence_file parameter in new().
diff --git a/fml/lib/File/Utils.pm b/fml/lib/File/Utils.pm
index 61df72ff..33485c20 100644
--- a/fml/lib/File/Utils.pm
+++ b/fml/lib/File/Utils.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Utils.pm,v 1.10 2002/01/13 06:59:50 fukachan Exp $
+# $FML: Utils.pm,v 1.11 2002/01/13 13:35:25 fukachan Exp $
#
package File::Utils;
@@ -146,7 +146,7 @@ The default search path list is
# Descriptions: search executable named as $file
-# Arguments: STR($file) HASH_ARRAY($path_list)
+# Arguments: STR($file) ARRAY_REF($path_list)
# The "path_list" is an ARRAY_REFERENCE.
# For example,
# search_program('md5');
diff --git a/fml/lib/IO/File/Atomic.pm b/fml/lib/IO/File/Atomic.pm
index 63332c95..fae18401 100644
--- a/fml/lib/IO/File/Atomic.pm
+++ b/fml/lib/IO/File/Atomic.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Atomic.pm,v 1.12 2002/01/13 06:13:41 fukachan Exp $
+# $FML: Atomic.pm,v 1.13 2002/02/02 08:04:54 fukachan Exp $
#
package IO::File::Atomic;
@@ -12,7 +12,6 @@ use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK);
use Carp;
use IO::File;
-
@ISA = qw(IO::File);
BEGIN {}
@@ -77,7 +76,7 @@ The request is forwarded to SUPER CLASS's new().
=cut
-# Descriptions: constructor
+# Descriptions: ordinary constructor
# forward new() request to superclass (IO::File)
# XXX returned object $self is blessed file handle.
# Arguments: OBJ($self)
@@ -171,7 +170,7 @@ After the file is closed, the file is renamed to the original file name.
# XXX $self is blessed file handle.
# Side Effects: rename the temporary file to the original file
# save the error message in ${ *$fh }
-# Return Value: 1 if succeeded, 0 if failed
+# Return Value: NUM(1 if succeeded, 0 if failed)
sub close
{
my ($self) = @_;
@@ -203,7 +202,7 @@ C<IO::File::Atomic::rw_open>.
# Descriptions: copy file, which ensures atomic operation
# Arguments: OBJ($self) STR($src) STR($dst)
# Side Effects: $dst's file mode becomes the same as $src
-# Return Value: NUM or UNDEF
+# Return Value: NUM
sub copy
{
my ($self, $src, $dst) = @_;
diff --git a/fml/lib/Mail/Delivery/Queue.pm b/fml/lib/Mail/Delivery/Queue.pm
index 2ffeae3e..81435894 100644
--- a/fml/lib/Mail/Delivery/Queue.pm
+++ b/fml/lib/Mail/Delivery/Queue.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Queue.pm,v 1.12 2002/01/30 15:50:31 fukachan Exp $
+# $FML: Queue.pm,v 1.13 2002/04/07 12:25:26 fukachan Exp $
#
package Mail::Delivery::Queue;
@@ -190,7 +190,7 @@ where C<$qid> is like this: 990157187.20792.1
# Descriptions: return queue file list
# Arguments: OBJ($self)
# Side Effects: none
-# Return Value: HASH_ARRAY
+# Return Value: ARRAY_REF
sub list
{
my ($self) = @_;
diff --git a/fml/lib/Mail/Message.pm b/fml/lib/Mail/Message.pm
index aa67b415..58ab2c70 100644
--- a/fml/lib/Mail/Message.pm
+++ b/fml/lib/Mail/Message.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Message.pm,v 1.48 2002/02/01 12:03:59 fukachan Exp $
+# $FML: Message.pm,v 1.49 2002/04/07 14:51:15 tmu Exp $
#
package Mail::Message;
@@ -534,7 +534,7 @@ sub _parse
# get reverse_path if possible.
# Arguments: OBJ($self) HASH_REF($r)
# Side Effects: update $r
-# Return Value: HASH_ARRAY
+# Return Value: ARRAY_REF
sub _parse_header
{
my ($self, $r) = @_;
@@ -1816,7 +1816,7 @@ sub nth_paragraph
# Descriptions: analyze paragraph position map in this object
# Arguments: OBJ($self)
# Side Effects: none
-# Return Value: HASH_ARRAY
+# Return Value: ARRAY_REF
sub _evaluate_pmap
{
my ($self) = @_;
diff --git a/fml/lib/Mail/Message/MH.pm b/fml/lib/Mail/Message/MH.pm
index 019348c4..a8e109c5 100644
--- a/fml/lib/Mail/Message/MH.pm
+++ b/fml/lib/Mail/Message/MH.pm
@@ -2,7 +2,7 @@
#
# Copyright (C) 2000 Ken'ichi Fukamachi
#
-# $FML: MH.pm,v 1.2 2001/12/22 09:21:19 fukachan Exp $
+# $FML: MH.pm,v 1.3 2001/12/24 02:26:34 fukachan Exp $
#
package Mail::Message::MH;
@@ -39,7 +39,7 @@ return HASH ARRAY of numbers specified by the following format:
# Descriptions: expand MH style expression to list of numbers
# Arguments: OBJ($self) STR($str) NUM($min) NUM($max)
# Side Effects: none
-# Return Value: HASH_ARRAY
+# Return Value: ARRAY_REF
sub expand
{
my ($self, $str, $min, $max) = @_;
@@ -89,7 +89,7 @@ sub expand
# Descriptions: make an array from $fist to $last number
# Arguments: NUM($first_number) NUM($last_number)
# Side Effects: none
-# Return Value: HASH_ARRAY as [ $first .. $last ]
+# Return Value: ARRAY_REF as [ $first .. $last ]
sub _expand_range
{
my ($first, $last) = @_;
diff --git a/fml/lib/FML/Process/CGI/Param.pm b/fml/lib/FML/Process/CGI/Param.pm
index 57b564f6..67cb3ff1 100644
--- a/fml/lib/FML/Process/CGI/Param.pm
+++ b/fml/lib/FML/Process/CGI/Param.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Param.pm,v 1.12 2002/03/18 13:52:20 fukachan Exp $
+# $FML: Param.pm,v 1.13 2002/03/19 07:59:52 fukachan Exp $
#
package FML::Process::CGI::Param;
@@ -78,16 +78,16 @@ sub safe_param
=head2 safe_paramlist($self, $numregexp, $key)
-return HASH_ARRAY for $key.
+return ARRAY_REF for $key.
=cut
# Descriptions: return HASH_ARRAY for key if the value is appropriate.
# Arguments: OBJ($self) NUM($numregexp) STR($key)
# Side Effects: none
# History: similar to fml 4.0's SecureP() and libcgi_cleanup.pl
-# Return Value: HASH_ARRAY
+# Return Value: ARRAY_REF
sub safe_paramlist
{
my ($self, $numregexp, $key) = @_;
@@ -78,16 +78,16 @@ sub safe_param
=cut
-# Descriptions: return HASH_ARRAY for key if the value is appropriate.
+# Descriptions: return ARRAY_REF for key if the value is appropriate.
# Arguments: OBJ($self) NUM($numregexp) STR($key)
# Side Effects: none